@@ -17,7 +17,7 @@ needs_sphinx = '2.0'
 # Add any Sphinx extension module names here, as strings. They can be
 # extensions coming with Sphinx (named 'sphinx.ext.*') or your custom
 # ones.
-extensions = ['sphinx_click']
+extensions = ['sphinx_click', 'reno.sphinxext']
 
 # The suffix(es) of source filenames.
 # You can specify multiple suffix as a list of string:
