@@ -3,5 +3,5 @@ from setuptools import find_packages, setup
 setup(
     name='sphinx_click_examples',
     packages=find_packages('.'),
-    install_requires=['click']
+    install_requires=['click'],
 )
